# fondat-postgresql

[![PyPI](https://badge.fury.io/py/fondat-postgresql.svg)](https://badge.fury.io/py/fondat-postgresql)
[![License](https://img.shields.io/github/license/fondat/fondat-postgresql.svg)](https://github.com/fondat/fondat-postgresql/blob/main/LICENSE)
[![GitHub](https://img.shields.io/badge/github-main-blue.svg)](https://github.com/fondat/fondat-postgresql/)
[![Test](https://github.com/fondat/fondat-postgresql/workflows/test/badge.svg)](https://github.com/fondat/fondat-postgresql/actions?query=workflow/test)
[![Black](https://img.shields.io/badge/code%20style-black-black.svg)](https://github.com/psf/black)

Fondat module for PostgreSQL.

## Develop

```
poetry install
poetry run pre-commit install
```

## Test

```
poetry run pytest
```
